@@ -69,15 +69,25 @@ class Items(list):
     the methods still work.
 
     """
-    __slots__ = ()
+    __slots__ = ('_arg',)
+
+    def __init__(self, arg, iterable=()):
+        """Items is initialized with the lexicon's argument."""
+        self._arg = arg
+        super().__init__(iterable)
 
     def __getitem__(self, n):
         """Reimplemented to return an Items instance when slicing."""
         result = super().__getitem__(n)
         if isinstance(n, slice):
-            return type(self)(result)
+            return type(self)(self.arg, result)
         return result
 
+    @property
+    def arg(self):
+        """The lexicon's argument (if any)."""
+        return self._arg
+
     def tokens(self, *texts):
         """Yield only the tokens, ignoring Item objects that represent
         sub-contexts.
@@ -175,8 +185,7 @@ class Transformer(parce.util.Observable):
     """
     def __init__(self):
         super().__init__()
-        self._lock = threading.Lock()   # for instantiating Transforms
-        self._transforms = {}
+        self._transforms = parce.util.caching_dict(self.find_transform)
         self._cache = weakref.WeakKeyDictionary()
         self._interrupt = weakref.WeakKeyDictionary()
 
@@ -195,13 +204,11 @@ class Transformer(parce.util.Observable):
         curlang = root_lexicon.language
         transform = self.get_transform(curlang)
 
-        items = Items()
+        items = Items(root_lexicon.arg)
         stack = []
         events = parce.lexer.Lexer([root_lexicon]).events(text, pos)
         lexicon = root_lexicon
 
-        no_object = object()                # sentinel for missing method
-
         def get_object_item(items):
             """Get the object item, may update curlang and transform variables."""
             nonlocal curlang, transform
@@ -210,18 +217,19 @@ class Transformer(parce.util.Observable):
                 transform = self.get_transform(curlang)
             name = lexicon.name
             meth = getattr(transform, name, None)
-            return Item(name, meth(items)) if meth else no_object
+            if meth:
+                return Item(name, meth(items))
 
         for e in events:
             if e.target:
                 for _ in range(e.target.pop, 0):
                     item = get_object_item(items)
                     lexicon, items = stack.pop()
-                    if item is not no_object:
+                    if item:
                         items.append(item)
                 for l in e.target.push:
                     stack.append((lexicon, items))
-                    items = Items()
+                    items = Items(l.arg)
                     lexicon = l
             items.extend(make_tokens(e))
 
@@ -229,10 +237,11 @@ class Transformer(parce.util.Observable):
         while stack:
             item = get_object_item(items)
             lexicon, items = stack.pop()
-            if item is not no_object:
+            if item:
                 items.append(item)
         item = get_object_item(items)
-        return None if item is no_object else item.obj
+        if item:
+            return item.obj
 
     def transform_tree(self, tree):
         """Evaluate a tree structure."""
@@ -243,44 +252,40 @@ class Transformer(parce.util.Observable):
 
         curlang = tree.lexicon.language
         transform = self.get_transform(curlang)
-
-        stack = []
-        node, items, i = tree, Items(), 0
-        while not self._interrupt[tree]:
-            for i in range(i, len(node)):
-                n = node[i]
-                if n.is_token:
-                    items.append(n)
+        root_meth = getattr(transform, tree.lexicon.name, None)
+        if root_meth:
+            stack = []
+            node, items, i = tree, Items(tree.lexicon.arg), 0
+            while not self._interrupt[tree]:
+                for i in range(i, len(node)):
+                    n = node[i]
+                    if n.is_token:
+                        items.append(n)
+                    else:
+                        # a context; do we have a method for it?
+                        if curlang is not n.lexicon.language:
+                            curlang = n.lexicon.language
+                            transform = self.get_transform(curlang)
+                        name = n.lexicon.name
+                        meth = getattr(transform, name, None)
+                        # don't bother going in this context if there is no method
+                        if meth:
+                            try:
+                                items.append(Item(name, self._cache[n]))
+                            except KeyError:
+                                stack.append((items, i + 1, meth))
+                                node, items, i = n, Items(n.lexicon.arg), 0
+                                break
                 else:
-                    # a context; do we have a method for it?
-                    if curlang is not n.lexicon.language:
-                        curlang = n.lexicon.language
-                        transform = self.get_transform(curlang)
-                    name = n.lexicon.name
-                    meth = getattr(transform, name, None)
-                    # don't bother going in this context is there is no method
-                    if meth:
-                        try:
-                            items.append(Item(name, self._cache[n]))
-                        except KeyError:
-                            stack.append((items, i + 1))
-                            node, items, i = n, Items(), 0
-                            break
-            else:
-                if curlang is not node.lexicon.language:
-                    curlang = node.lexicon.language
-                    transform = self.get_transform(curlang)
-                name = node.lexicon.name
-                meth = getattr(transform, name, None)
-                obj = meth(items) if meth else None
-                if stack:
-                    self._cache[node] = obj
-                    items, i = stack.pop()
-                    items.append(Item(name, obj))
-                    node = node.parent
-                else:
-                    break
-        return obj
+                    if stack:
+                        name = node.lexicon.name
+                        olditems, i, meth = stack.pop()
+                        obj = self._cache[node] = meth(items)
+                        items = olditems
+                        items.append(Item(name, obj))
+                        node = node.parent
+                    else:
+                        return root_meth(items)
 
     def build(self, tree):
         """Called when a tree needs to be transformed.
@@ -372,15 +377,7 @@ class Transformer(parce.util.Observable):
 
     def get_transform(self, language):
         """Return a Transform class instance for the specified language."""
-        try:
-            return self._transforms[language]
-        except KeyError:
-            with self._lock:
-                try:
-                    tf = self._transforms[language]
-                except KeyError:
-                    tf = self._transforms[language] = self.find_transform(language)
-                return tf
+        return self._transforms[language]
 
     def add_transform(self, language, transform):
         """Add a Transform instance for the specified language."""
